@@ -109,7 +109,10 @@ class Manaba:
         self.__response.raise_for_status()
         soup = BeautifulSoup(self.__response.text, "html5lib")
 
-        title = soup.find("a", {"id": "coursename"}).text
+        if soup.find("a", {"id": "coursename"}).has_attr("title"):
+            title = soup.find("a", {"id": "coursename"}).get("title")
+        else:
+            title = soup.find("a", {"id": "coursename"}).text
         teacher = soup.find("span", {"class": "courseteacher"}).text
         lecture_at = soup.find("span", {"class": "coursedata-info"}).find("span").text
         year = int(soup.find("span", {"class": "coursedata-info"}).text.replace(lecture_at, ""))
@@ -1336,6 +1339,10 @@ class Manaba:
                 your_status = ManabaTaskYourStatusFlag.UNSUBMITTED
             elif "回提出済み" in statuses[1]:  # ドリル対策。未合格で締め切られている場合「n回提出済み」になる？
                 your_status = ManabaTaskYourStatusFlag.UNPASSED
+            elif "受験回数" in statuses[1]:  # ドリル対策。未合格で締め切られている場合「受験回数: n」になる
+                your_status = ManabaTaskYourStatusFlag.UNPASSED
+            elif "個別指導／相互閲覧画面へ" in statuses[1] and task_status == ManabaTaskStatusFlag.CLOSED:  # タスククローズ + 未提出？
+                your_status = ManabaTaskYourStatusFlag.UNSUBMITTED
             else:
                 your_status = get_your_status(statuses[1].strip())
                 if your_status is None:
